# joi-intersection

Validate against intersections of arrays and array singletons. Provide an array of allowed groups and validate it 
against a single intersection of a given group. Additionally, define an array of singletons and verify the input array
occurs only once.

## API

- `groups: Function`
    - `allowed: Array<Array<String>>` Allowed intersection groups
- `singleton: Function`
    - `allowed: Array<String>` Allowed singleton
    
## Usage

Install the package:

```js
npm install joi-intersection --save
```

You have to extend Joi first, then use it like other validation rules. You can also chain both rules.

```js
import JoiBase from 'joi'
import JoiIntersection from 'joi-intersection'
import * as assert from 'assert'

const Joi = JoiBase.extend(JoiIntersection)
```


### Groups

```js
const schema = Joi.array().groups([
  ['Bob', 'Alex', 'Peter'],
  ['Jack', 'Mike']
])

Joi.validate(['Bob', 'Alex'], schema, error => assert.ok(error, null))
Joi.validate(['Bob', 'Jack'], schema, error => assert.notEqual(error, null))
```

### Singleton

```js
const schema = Joi.array().singleton(['Bob', 'Alex', 'Peter'])

Joi.validate(['Bob'], schema, error => assert.ok(error, null))
Joi.validate(['Bob', 'Bob'], schema, error => assert.notEqual(error, null))
```